==> rong-ui-react-0.0.5.tgz: package/es/flex-fixed/flex-fixed.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { forwardRef, useState, useRef, useEffect, memo } from 'react';
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
import withPreventScroll from '../_hoc/withPreventScroll';
var prefixCls = 'r-flexfixed';
var FlexFixed = /*#__PURE__*/forwardRef(function (props, ref) {
  var header = props.header,
      footer = props.footer,
      extra = props.extra,
      children = props.children,
      className = props.className,
      onScroll = props.onScroll,
      onScrollDebounce = props.onScrollDebounce,
      withPreventScroll = props.withPreventScroll,
      hideFooterOnKeyboardShow = props.hideFooterOnKeyboardShow;
  var doc = document.documentElement || document.body;

  var _useState = useState(true),
      _useState2 = _slicedToArray(_useState, 2),
      showFooter = _useState2[0],
      setShowFooter = _useState2[1];

  var _useState3 = useState(doc.clientHeight),
      _useState4 = _slicedToArray(_useState3, 1),
      docHeight = _useState4[0];

  var wrapCls = classNames([prefixCls, className]);
  var innerCls = "".concat(prefixCls, "-inner");
  var flexFixedRef = useRef();

  var onMainTouchStart = function onMainTouchStart(e) {
    var main = e.currentTarget;
    main.maxScrollTop = main.scrollHeight - main.offsetHeight;
  };

  var onMainScroll = function onMainScroll(e) {
    var main = e.currentTarget;
    var scrollTop = main.scrollTop;
    var direction = '';

    if (scrollTop > main.prevScrollTop) {
      direction = 'up';
    } else if (scrollTop < main.prevScrollTop) {
      direction = 'down';
    }

    if (e.target.timer) clearTimeout(e.target.timer);
    e.target.timer = setTimeout(function () {
      onScrollDebounce && onScrollDebounce({
        scrollTop: main.scrollTop,
        maxScrollTop: main.maxScrollTop,
        direction: direction
      });
    }, 150);
    onScroll && onScroll({
      scrollTop: main.scrollTop,
      maxScrollTop: main.maxScrollTop,
      direction: direction
    });
    main.prevScrollTop = scrollTop;
  }; // 阻止页面滚动


  useEffect(function () {
    withPreventScroll && withPreventScroll.init({
      el: flexFixedRef.current
    });
  }, [withPreventScroll]); // 安卓键盘弹起时隐藏footer

  useEffect(function () {
    if (hideFooterOnKeyboardShow) {
      var hideFooterOnScroll = function hideFooterOnScroll() {
        setShowFooter(doc.scrollTop === 0);
      };

      var hideFooterOnResize = function hideFooterOnResize() {
        setShowFooter(doc.clientHeight / docHeight > 0.8);
      };

      document.addEventListener('scroll', hideFooterOnScroll, false);
      window.addEventListener('resize', hideFooterOnResize, false);
      return function () {
        document.removeEventListener('scroll', hideFooterOnScroll, false);
        window.removeEventListener('resize', hideFooterOnResize, false);
      };
    }
  }, []);
  console.log('flexfixed mounted or updated');
  return /*#__PURE__*/React.createElement("div", {
    className: wrapCls,
    ref: flexFixedRef
  }, /*#__PURE__*/React.createElement("div", {
    className: innerCls
  }, header && /*#__PURE__*/React.createElement("header", null, header), /*#__PURE__*/React.createElement("main", {
    className: "scroll-area",
    onScroll: onMainScroll,
    onTouchStart: onMainTouchStart
  }, children), footer && /*#__PURE__*/React.createElement("footer", {
    style: {
      display: showFooter ? '' : 'none'
    }
  }, footer)), extra);
});
setDefaultProps(FlexFixed, {
  className: {
    type: PropTypes.string
  },
  header: {
    type: PropTypes.node
  },
  footer: {
    type: PropTypes.node
  },
  extra: {
    type: PropTypes.node
  },
  onScroll: {
    type: PropTypes.func
  },
  onScrollDebounce: {
    type: PropTypes.func
  },
  hideFooterOnKeyboardShow: {
    type: PropTypes.bool,
    default: true
  }
});
export default withPreventScroll( /*#__PURE__*/memo(FlexFixed));

==> rong-ui-react-0.0.8.tgz: package/es/flex-fixed/flex-fixed.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import React, { forwardRef, useState, useRef, useEffect, memo } from 'react';
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
import withPreventScroll from '../_hoc/withPreventScroll';
var prefixCls = 'r-flexfixed';
var FlexFixed = /*#__PURE__*/forwardRef(function (props, ref) {
  var header = props.header,
    footer = props.footer,
    extra = props.extra,
    children = props.children,
    className = props.className,
    onScroll = props.onScroll,
    onScrollDebounce = props.onScrollDebounce,
    withPreventScroll = props.withPreventScroll,
    hideFooterOnKeyboardShow = props.hideFooterOnKeyboardShow;
  var doc = document.documentElement || document.body;
  var _useState = useState(true),
    _useState2 = _slicedToArray(_useState, 2),
    showFooter = _useState2[0],
    setShowFooter = _useState2[1];
  var _useState3 = useState(doc.clientHeight),
    _useState4 = _slicedToArray(_useState3, 1),
    docHeight = _useState4[0];
  var wrapCls = classNames([prefixCls, className]);
  var innerCls = "".concat(prefixCls, "-inner");
  var flexFixedRef = useRef();
  var onMainTouchStart = function onMainTouchStart(e) {
    var main = e.currentTarget;
    main.maxScrollTop = main.scrollHeight - main.offsetHeight;
  };
  var onMainScroll = function onMainScroll(e) {
    var main = e.currentTarget;
    var scrollTop = main.scrollTop;
    var direction = '';
    if (scrollTop > main.prevScrollTop) {
      direction = 'up';
    } else if (scrollTop < main.prevScrollTop) {
      direction = 'down';
    }
    if (e.target.timer) clearTimeout(e.target.timer);
    e.target.timer = setTimeout(function () {
      onScrollDebounce && onScrollDebounce({
        scrollTop: main.scrollTop,
        maxScrollTop: main.maxScrollTop,
        direction: direction
      });
    }, 150);
    onScroll && onScroll({
      scrollTop: main.scrollTop,
      maxScrollTop: main.maxScrollTop,
      direction: direction
    });
    main.prevScrollTop = scrollTop;
  };

  // 阻止页面滚动
  useEffect(function () {
    withPreventScroll && withPreventScroll.init({
      el: flexFixedRef.current
    });
  }, [withPreventScroll]);

  // 安卓键盘弹起时隐藏footer
  useEffect(function () {
    if (hideFooterOnKeyboardShow) {
      var hideFooterOnScroll = function hideFooterOnScroll() {
        setShowFooter(doc.scrollTop === 0);
      };
      var hideFooterOnResize = function hideFooterOnResize() {
        setShowFooter(doc.clientHeight / docHeight > 0.8);
      };
      document.addEventListener('scroll', hideFooterOnScroll, false);
      window.addEventListener('resize', hideFooterOnResize, false);
      return function () {
        document.removeEventListener('scroll', hideFooterOnScroll, false);
        window.removeEventListener('resize', hideFooterOnResize, false);
      };
    }
  }, []);
  console.log('flexfixed mounted or updated');
  return /*#__PURE__*/React.createElement("div", {
    className: wrapCls,
    ref: flexFixedRef
  }, /*#__PURE__*/React.createElement("div", {
    className: innerCls
  }, header && /*#__PURE__*/React.createElement("header", null, header), /*#__PURE__*/React.createElement("main", {
    className: "scroll-area",
    onScroll: onMainScroll,
    onTouchStart: onMainTouchStart
  }, children), footer && /*#__PURE__*/React.createElement("footer", {
    style: {
      display: showFooter ? '' : 'none'
    }
  }, footer)), extra);
});
setDefaultProps(FlexFixed, {
  className: {
    type: PropTypes.string
  },
  header: {
    type: PropTypes.node
  },
  footer: {
    type: PropTypes.node
  },
  extra: {
    type: PropTypes.node
  },
  onScroll: {
    type: PropTypes.func
  },
  onScrollDebounce: {
    type: PropTypes.func
  },
  hideFooterOnKeyboardShow: {
    type: PropTypes.bool,
    default: true
  }
});
export default withPreventScroll( /*#__PURE__*/memo(FlexFixed));
